==> flutter_custom_form_component-0.0.3.tar.gz: lib/widget/field/money/formatter.dart <==
import 'package:flutter/services.dart';

class MoneyFormatter extends TextInputFormatter {
  late final String _decimalSeparator, _thousandSeparator;
  late final String? _symbol;

  MoneyFormatter(
      {required String decimalSeparator,
      String? symbol,
      required String thousandSeparator}) {
    _decimalSeparator = decimalSeparator;
    _symbol = symbol;
    _thousandSeparator = thousandSeparator;
  }

  @override
  TextEditingValue formatEditUpdate(
      final TextEditingValue oldValue, final TextEditingValue newValue) {
    // If cursor doesn't at the end then take the old value.
    String value = newValue.selection.end == newValue.text.length
        ? newValue.text
        : oldValue.text;

    // Replace all thousand separators then decimal separators.
    value = value.replaceAll(_thousandSeparator, '');

    // Remove invalid decimals.
    final List<String> strings = value.split(_decimalSeparator);
    value =
        '${strings[0]}${strings.length > 1 ? '$_decimalSeparator${strings[1]}' : ''}';

    // Remove symbol.
    if (_symbol != null) {
      value = value.replaceFirst(_symbol!, '');
    }

    StringBuffer buffer = StringBuffer();

    // Remove zero prefixs
    bool isZeroPrefix = true;
    for (int index = 0; index < value.length; index++) {
      if (value[index] == '0') {
        if (!isZeroPrefix) {
          buffer.write(value[index]);
        }
      } else {
        buffer.write(value[index]);
        if (isZeroPrefix) {
          isZeroPrefix = false;
        }
      }
    }
    value = buffer.toString();

    // Write symbol at beginning.
    buffer = StringBuffer(_symbol ?? '');

    int decimalDigits = 0; // digit amount after decimal separator.
    int calibratedIndex;
    final StringBuffer reversed = StringBuffer();

    // Reverse value to formatting thousands.
    for (int index = value.length - 1; index >= 0; index--) {
      if (value.contains(_decimalSeparator) &&
          !reversed.toString().contains(_decimalSeparator)) {
        // decimals
        decimalDigits++;
      } else {
        // non decimals
        calibratedIndex = value.length - index - decimalDigits;
        if (calibratedIndex > 1 && calibratedIndex % 3 == 1) {
          reversed.write(_thousandSeparator);
        }
      }
      reversed.write(value[index]);
    }

    value = reversed.toString();
    // Reverse back.
    for (int index = value.length - 1; index >= 0; index--) {
      buffer.write(value[index]);
    }

    return TextEditingValue(
        selection: TextSelection.collapsed(offset: buffer.length),
        text: buffer.toString());
  }
}

==> flutter_custom_form_component-0.0.5.tar.gz: lib/widget/field/money/formatter.dart <==
import 'package:flutter/services.dart';

/// Money input formatter supports money symbol, thousand separators and decimal separator.
class MoneyFormatter extends TextInputFormatter {
  late final String _decimalSeparator, _thousandSeparator;
  late final String? _symbol;

  MoneyFormatter(
      {required String decimalSeparator,
      String? symbol,
      required String thousandSeparator}) {
    _decimalSeparator = decimalSeparator;
    _symbol = symbol;
    _thousandSeparator = thousandSeparator;
  }

  @override
  TextEditingValue formatEditUpdate(
      final TextEditingValue oldValue, final TextEditingValue newValue) {
    /// If cursor doesn't at the end then take the old value.
    String value = newValue.selection.end == newValue.text.length
        ? newValue.text
        : oldValue.text;

    /// Replace all thousand separators then decimal separators.
    value = value.replaceAll(_thousandSeparator, '');

    /// Remove invalid decimals.
    final List<String> strings = value.split(_decimalSeparator);
    value =
        '${strings[0]}${strings.length > 1 ? '$_decimalSeparator${strings[1]}' : ''}';

    /// Remove symbol.
    if (_symbol != null) {
      value = value.replaceFirst(_symbol!, '');
    }

    StringBuffer buffer = StringBuffer();

    /// Remove zero prefixs
    bool isZeroPrefix = true;
    for (int index = 0; index < value.length; index++) {
      if (value[index] == '0') {
        if (!isZeroPrefix) {
          buffer.write(value[index]);
        }
      } else {
        buffer.write(value[index]);
        if (isZeroPrefix) {
          isZeroPrefix = false;
        }
      }
    }
    value = buffer.toString();

    /// Write symbol at beginning.
    buffer = StringBuffer(_symbol ?? '');

    int decimalDigits = 0; // digit amount after decimal separator.
    int calibratedIndex;
    final StringBuffer reversed = StringBuffer();

    /// Reverse value to formatting thousands.
    for (int index = value.length - 1; index >= 0; index--) {
      if (value.contains(_decimalSeparator) &&
          !reversed.toString().contains(_decimalSeparator)) {
        /// decimals
        decimalDigits++;
      } else {
        /// non decimals
        calibratedIndex = value.length - index - decimalDigits;
        if (calibratedIndex > 1 && calibratedIndex % 3 == 1) {
          reversed.write(_thousandSeparator);
        }
      }
      reversed.write(value[index]);
    }

    value = reversed.toString();

    /// Reverse back.
    for (int index = value.length - 1; index >= 0; index--) {
      buffer.write(value[index]);
    }

    return TextEditingValue(
        selection: TextSelection.collapsed(offset: buffer.length),
        text: buffer.toString());
  }
}
